@@ -24,16 +24,17 @@ class ClientModel(ABC):
         self.__setitem__('heartbeat_required', self.heartbeat_required)
         self.date_created = date_created
         self.__setitem__('date_created', self.date_created)
-        if match_list and match_case == "exact":
-            for key in _dict.keys():
-                for i in match_list:
-                    if i.lower() == key.lower():
-                        self.__setitem__(key, _dict[key])
-        elif match_list and match_case == "insensitive":
-            for key in _dict.keys():
-                for i in match_list:
-                    if i.lower() in key.lower():
-                        self.__setitem__(key, _dict[key])
+        if match_list:
+            if match_case == "exact" or match_case == "sensitive":
+                for key in _dict.keys():
+                    for i in match_list:
+                        if i.lower() == key.lower():
+                            self.__setitem__(key, _dict[key])
+            elif match_case == "insensitive":
+                for key in _dict.keys():
+                    for i in match_list:
+                        if i.lower() in key.lower():
+                            self.__setitem__(key, _dict[key])
         elif _dict:
             self.dict.update(_dict)
         self.validate()
